@@ -1,6 +1,6 @@
 # Ebay/ByEndDate.pm
 # by Martin Thurn
-# $Id: ByEndDate.pm,v 1.1 2003-02-06 23:35:18-05 kingpin Exp kingpin $
+# $Id: ByEndDate.pm,v 2.21 2004/04/08 18:31:57 Daddy Exp $
 
 =head1 NAME
 
@@ -84,9 +84,12 @@ package WWW::Search::Ebay::ByEndDate;
 
 use Carp;
 use WWW::Search::Ebay;
-@ISA = qw( WWW::Search::Ebay );
 
-$VERSION = '2.02';
+use strict;
+use vars qw( @ISA $VERSION $MAINTAINER );
+
+@ISA = qw( WWW::Search::Ebay );
+$VERSION = do { my @r = (q$Revision: 2.21 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 $MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';
 
 # private
@@ -103,6 +106,31 @@ sub native_setup_search
   return $self->SUPER::native_setup_search($native_query, $rhOptsArg);
   } # native_setup_search
 
+# Enforce sorting by end date, even if Ebay is returning it in a
+# different order.  Calls parse_tree() of the base class, and then
+# reshuffles its 'cache' results.  Code contributed by Mike Schilli.
+
+sub parse_tree
+  {
+  my ($self, @args) = @_;
+  my $hits = $self->SUPER::parse_tree(@args);
+  $self->{cache} ||= [];
+  $self->{cache} = [sort { minutes($a->change_date()) <=>
+                           minutes($b->change_date()) }
+                    @{$self->{cache}}];
+  return $hits;
+  } # parse_tree
+
+sub minutes
+  {
+  my ($s) = @_;
+  my $min = 0;
+  $min += 60*24*$1 if $s =~ /(\d+)[dT]/;
+  $min += 60*$1 if $s =~ /(\d+)[hS]/;
+  $min += $1 if $s =~ /(\d+)[mM]/;
+  return $min;
+  } # minutes
+
 1;
 
 __END__
